@@ -112,7 +112,7 @@ NEOERR *ne_net_accept(NSOCK **sock, int sfd, int data_timeout)
   NSOCK *my_sock;
   int fd;
   struct sockaddr_in client_addr;
-  int len;
+  socklen_t len;
 
   len = sizeof(struct sockaddr_in);
   while (1)
@@ -146,8 +146,8 @@ NEOERR *ne_net_accept(NSOCK **sock, int sfd, int data_timeout)
 }
 
 /* Client side */
-NEOERR *ne_net_connect(NSOCK **sock, char *host, int port, int conn_timeout, 
-    int data_timeout)
+NEOERR *ne_net_connect(NSOCK **sock, const char *host, int port, 
+                       int conn_timeout, int data_timeout)
 {
   struct sockaddr_in serv_addr;
   struct hostent hp;
@@ -158,7 +158,7 @@ NEOERR *ne_net_connect(NSOCK **sock, char *host, int port, int conn_timeout,
   struct timeval tv;
   fd_set fds;
   int optval;
-  int optlen;
+  socklen_t optlen;
   NSOCK *my_sock;
 
   /* FIXME: This isn't thread safe... but there's no man entry for the _r
@@ -456,14 +456,14 @@ NEOERR *ne_net_read_line(NSOCK *sock, char **buf)
       if (nl == NULL)
       {
 	l = sock->il - sock->ib;
-	err = string_appendn(&str, sock->ibuf + sock->ib, l);
+	err = string_appendn(&str, (char *)(sock->ibuf + sock->ib), l);
 	sock->ib += l;
 	if (err) break;
       }
       else
       {
 	l = nl - (sock->ibuf + sock->ib);
-	err = string_appendn(&str, sock->ibuf + sock->ib, l);
+	err = string_appendn(&str, (char *)(sock->ibuf + sock->ib), l);
 	sock->ib += l;
 	if (err) break;
 
@@ -521,7 +521,7 @@ NEOERR *ne_net_read_binary(NSOCK *sock, UINT8 **b, int *blen)
 {
   NEOERR *err;
   UINT8 *data;
-  char buf[5];
+  UINT8 buf[5];
   int l;
 
   err = _ne_net_read_int(sock, &l, ':');
@@ -589,7 +589,7 @@ NEOERR *ne_net_read_int(NSOCK *sock, int *i)
   return nerr_pass(_ne_net_read_int(sock, i, ','));
 }
 
-NEOERR *ne_net_write(NSOCK *sock, UINT8 *b, int blen)
+NEOERR *ne_net_write(NSOCK *sock, const char *b, int blen)
 {
   NEOERR *err;
   int x = 0;
@@ -622,7 +622,7 @@ NEOERR *ne_net_write(NSOCK *sock, UINT8 *b, int blen)
   return STATUS_OK;
 }
 
-NEOERR *ne_net_write_line(NSOCK *sock, char *s)
+NEOERR *ne_net_write_line(NSOCK *sock, const char *s)
 {
   NEOERR *err;
 
@@ -633,7 +633,7 @@ NEOERR *ne_net_write_line(NSOCK *sock, char *s)
   return STATUS_OK;
 }
 
-NEOERR *ne_net_write_binary(NSOCK *sock, UINT8 *b, int blen)
+NEOERR *ne_net_write_binary(NSOCK *sock, const char *b, int blen)
 {
   NEOERR *err;
   char buf[32];
@@ -655,7 +655,7 @@ NEOERR *ne_net_write_binary(NSOCK *sock, UINT8 *b, int blen)
   return STATUS_OK;
 }
 
-NEOERR *ne_net_write_str(NSOCK *sock, char *s)
+NEOERR *ne_net_write_str(NSOCK *sock, const char *s)
 {
   NEOERR *err;
 
